import { PostState, PostStateLabels } from '@nice/common';
import {
    ExclamationCircleOutlined,
    BulbOutlined,
    QuestionCircleOutlined,
    CommentOutlined,
    ClockCircleOutlined,
    SyncOutlined,
    CheckCircleOutlined,
    TagOutlined,
} from '@ant-design/icons';

export const BADGE_STYLES = {
    category: {
        complaint: {
            bg: "bg-gradient-to-r from-orange-50 to-orange-100",
            text: "text-orange-800",
            border: "border-orange-200",
            icon: <ExclamationCircleOutlined className="text-orange-500" />,
            hover: "hover:from-orange-100 hover:to-orange-200",
        },
        suggestion: {
            bg: "bg-gradient-to-r from-blue-50 to-blue-100",
            text: "text-blue-800",
            border: "border-blue-200",
            icon: <BulbOutlined className="text-blue-500" />,
            hover: "hover:from-blue-100 hover:to-blue-200",
        },
        request: {
            bg: "bg-gradient-to-r from-purple-50 to-purple-100",
            text: "text-purple-800",
            border: "border-purple-200",
            icon: <QuestionCircleOutlined className="text-purple-500" />,
            hover: "hover:from-purple-100 hover:to-purple-200",
        },
        feedback: {
            bg: "bg-gradient-to-r from-teal-50 to-teal-100",
            text: "text-teal-800",
            border: "border-teal-200",
            icon: <CommentOutlined className="text-teal-500" />,
            hover: "hover:from-teal-100 hover:to-teal-200",
        },
    },
    state: {
        [PostState.PENDING]: {
            bg: "bg-gradient-to-r from-yellow-50 to-yellow-100",
            text: "text-yellow-800",
            border: "border-yellow-200",
            icon: <ClockCircleOutlined className="text-yellow-500" />,
            hover: "hover:from-yellow-100 hover:to-yellow-200",
        },
        [PostState.PROCESSING]: {
            bg: "bg-gradient-to-r from-blue-50 to-blue-100",
            text: "text-blue-800",
            border: "border-blue-200",
            icon: <SyncOutlined className="text-blue-500" spin />,
            hover: "hover:from-blue-100 hover:to-blue-200",
        },
        [PostState.RESOLVED]: {
            bg: "bg-gradient-to-r from-green-50 to-green-100",
            text: "text-green-800",
            border: "border-green-200",
            icon: <CheckCircleOutlined className="text-green-500" />,
            hover: "hover:from-green-100 hover:to-green-200",
        },
    },
    tag: {
        default: {
            bg: "bg-gradient-to-r from-gray-50 to-gray-100",
            text: "text-gray-800",
            border: "border-gray-200",
            icon: <TagOutlined className="text-gray-500" />,
            hover: "hover:from-gray-100 hover:to-gray-200",
        }
    },
} as const;

export const getBadgeStyle = (
    type: keyof typeof BADGE_STYLES,
    value: string
) => {
    const style = type === 'tag'
        ? BADGE_STYLES.tag.default
        : BADGE_STYLES[type][value as keyof (typeof BADGE_STYLES)[typeof type]] || {
            bg: "bg-gradient-to-r from-gray-50 to-gray-100",
            text: "text-gray-800",
            border: "border-gray-200",
            icon: <TagOutlined className="text-gray-500" />,
            hover: "hover:from-gray-100 hover:to-gray-200",
        };

    return style;
};

export function LetterBadge({
    type,
    value,
    className = "",
}: {
    type: "category" | "state" | "tag";
    value: string;
    className?: string;
}) {
    if (!value) return null;

    const style = getBadgeStyle(type, value);

    return (
        <span
            className={`
                inline-flex items-center gap-1 px-2.5 py-1 rounded-full text-xs font-medium
                ${style.bg} ${style.text} ${style.hover}
                border ${style.border}
                shadow-sm backdrop-blur-sm
                transition-all duration-300 ease-out
                hover:shadow-md hover:-translate-y-0.5
                ${className}
            `}>
            {style.icon}
            <span className="tracking-wide">
                {type === 'state' ? PostStateLabels[value] : value}
            </span>
        </span>
    );
}
